import { NextRequest, NextResponse } from 'next/server';

export async function POST(request: NextRequest) {
  try {
    const { propertyIds } = await request.json();

    if (!propertyIds || !Array.isArray(propertyIds)) {
      return NextResponse.json({ error: 'propertyIds array is required' }, { status: 400 });
    }

    const cleanIds = propertyIds.map(id => id.replace('http://www.wikidata.org/prop/', ''));
    const propertyIdsStr = cleanIds.join(' wd:');
    
    const sparqlQuery = `
      SELECT ?prop ?propLabel WHERE {
        VALUES ?prop { wd:${propertyIdsStr} }
        SERVICE wikibase:label { bd:serviceParam wikibase:language "en". }
      }
    `;

    const url = `https://query.wikidata.org/sparql?query=${encodeURIComponent(sparqlQuery)}&format=json`;
    
    const response = await fetch(url, {
      headers: { 
        'Accept': 'application/json',
        'User-Agent': 'WikidataApp/1.0 (https://example.com/contact)'
      }
    });
    
    if (!response.ok) {
      throw new Error(`Wikidata SPARQL error: ${response.status}`);
    }
    
    const data = await response.json();
    const result: Record<string, string> = {};
    
    if (data.results?.bindings) {
      for (const binding of data.results.bindings) {
        const propUri = binding.prop?.value;
        const label = binding.propLabel?.value || '';
        
        if (propUri) {
          const propId = propUri.split('/').pop() || '';
          result[propId] = label;
        }
      }
    }
    
    return NextResponse.json(result);
  } catch (error) {
    console.error('Error fetching property labels:', error);
    return NextResponse.json({});
  }
}